#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LT_HPP_INCLUDED

#include <boost/simd/operator/include/functions/lt.hpp>

#endif
